"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const CJSON = require("comment-json");
const dependencies_1 = require("./dependencies");
const code_utils_1 = require("../utils/code-utils");
const yang_utils_1 = require("../utils/yang-utils");
function default_1(options) {
    return () => {
        return schematics_1.chain([
            addFiles(),
            updatePackageJson(),
            updateCore(),
            updateShared(),
            yang_utils_1.installDeps(options.skipInstall)
        ]);
    };
}
exports.default = default_1;
function addFiles() {
    return (tree) => {
        return schematics_1.mergeWith(schematics_1.apply(schematics_1.url('./files'), [
            schematics_1.move(''),
        ]), schematics_1.MergeStrategy.Overwrite);
    };
}
function updatePackageJson() {
    return (tree) => {
        const filePath = 'package.json';
        if (!tree.exists(filePath)) {
            throw new schematics_1.SchematicsException(`File ${filePath} does not exist.`);
        }
        const source = tree.read(filePath);
        if (!source) {
            throw new schematics_1.SchematicsException(`File ${filePath} is empty.`);
        }
        const json = CJSON.parse(source.toString('utf-8'));
        // Add dependencies
        json.dependencies = Object.assign(Object.assign({}, json.dependencies), dependencies_1.extraDevDependencies);
        // Sort dependencies by name
        json.dependencies = yang_utils_1.sortByKey(json.dependencies);
        tree.overwrite(filePath, CJSON.stringify(json, null, 2));
        return tree;
    };
}
function updateCore() {
    return (tree) => {
        const filePath = yang_utils_1.YangUtils.CORE_MODULE_FILE;
        if (!tree.exists(filePath)) {
            throw new schematics_1.SchematicsException(`File ${filePath} does not exist.`);
        }
        const sourceFile = code_utils_1.CodeUtils.readSourceFile(tree, filePath);
        code_utils_1.CodeUtils.addImport(sourceFile, 'I18NModule', './i18n.module');
        code_utils_1.CodeUtils.addImport(sourceFile, 'init as i18nInitializer', './i18n.initializer');
        code_utils_1.CodeUtils.insertInVariableArray(sourceFile, 'INITIALIZERS', 'i18nInitializer');
        code_utils_1.CodeUtils.insertInVariableArray(sourceFile, 'MODULES', 'I18NModule');
        code_utils_1.CodeUtils.writeSourceFile(tree, filePath, sourceFile);
        return tree;
    };
}
function updateShared() {
    return (tree) => {
        const filePath = yang_utils_1.YangUtils.SHARED_MODULE_FILE;
        if (!tree.exists(filePath)) {
            throw new schematics_1.SchematicsException(`File ${filePath} does not exist.`);
        }
        const sourceFile = code_utils_1.CodeUtils.readSourceFile(tree, filePath);
        code_utils_1.CodeUtils.addImport(sourceFile, 'TranslateModule', '@ngx-translate/core');
        code_utils_1.CodeUtils.insertInVariableArray(sourceFile, 'MODULES', 'TranslateModule');
        code_utils_1.CodeUtils.writeSourceFile(tree, filePath, sourceFile);
        return tree;
    };
}
//# sourceMappingURL=index.js.map