"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const workspace_1 = require("@schematics/angular/utility/workspace");
const dependencies_1 = require("./dependencies");
const yang_utils_1 = require("../utils/yang-utils");
const CJSON = require("comment-json");
function default_1(options) {
    return () => {
        return schematics_1.chain([
            updatePackageJson(),
            updateTsConfig(),
            updateProjectWorkspace(),
            addJestFiles(),
            removeKarmaFiles(),
            yang_utils_1.installDeps(options.skipInstall)
        ]);
    };
}
exports.default = default_1;
function updatePackageJson() {
    return (tree) => {
        const filePath = 'package.json';
        if (!tree.exists(filePath)) {
            throw new schematics_1.SchematicsException(`File ${filePath} does not exist.`);
        }
        const source = tree.read(filePath);
        if (!source) {
            throw new schematics_1.SchematicsException(`File ${filePath} is empty.`);
        }
        const json = CJSON.parse(source.toString('utf-8'));
        json.scripts = Object.assign(Object.assign({}, json.scripts), { 'test': 'jest', 'test:watch': 'jest --watch' });
        // Add Jest dependencies
        json.devDependencies = Object.assign(Object.assign({}, json.devDependencies), dependencies_1.extraDevDependencies);
        // Remove Karma
        const karmaDeps = Object.keys(json.devDependencies)
            .filter(k => k === 'karma' || k.startsWith('karma-'));
        karmaDeps.forEach(key => {
            delete json.devDependencies[key];
        });
        // Sort dependencies by name
        json.dependencies = yang_utils_1.sortByKey(json.dependencies);
        json.devDependencies = yang_utils_1.sortByKey(json.devDependencies);
        tree.overwrite(filePath, CJSON.stringify(json, null, 2));
        return tree;
    };
}
function updateTsConfig() {
    return (tree) => {
        const filePath = 'tsconfig.spec.json';
        const source = tree.read(filePath);
        if (!source) {
            throw new schematics_1.SchematicsException(`File ${filePath} is empty.`);
        }
        const json = CJSON.parse(source.toString('utf-8'));
        json.compilerOptions = Object.assign(Object.assign({}, json.compilerOptions), { "emitDecoratorMetadata": true, "types": ["jest", "node"] });
        json.files = json.files.filter((f) => f !== 'src/test.ts');
        tree.overwrite(filePath, CJSON.stringify(json, null, 2));
        return tree;
    };
}
function updateProjectWorkspace() {
    return (tree) => {
        return workspace_1.updateWorkspace(workspace => {
            const projectName = workspace.extensions.defaultProject;
            const project = workspace.projects.get(projectName);
            if (!project) {
                return;
            }
            // Add proxy config
            const test = project.targets.get('test');
            if (!test)
                throw new Error(`expected node projects/${projectName}/architect/test in angular.json`);
            test.builder = '@angular-builders/jest:run';
            delete test.options['main'];
            delete test.options['polyfills'];
            delete test.options['tsConfig'];
            delete test.options['karmaConfig'];
        });
    };
}
function addJestFiles() {
    return (tree) => {
        return schematics_1.mergeWith(schematics_1.apply(schematics_1.url('./files'), [
            schematics_1.move(''),
        ]), schematics_1.MergeStrategy.Overwrite);
    };
}
function removeKarmaFiles() {
    return (tree) => {
        const deleteFiles = [
            './karma.conf.js',
            './src/test.ts'
        ];
        deleteFiles.forEach((filePath) => {
            if (tree.exists(filePath)) {
                tree.delete(filePath);
            }
        });
        return tree;
    };
}
//# sourceMappingURL=index.js.map