"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const core_1 = require("@angular-devkit/core");
const code_utils_1 = require("../utils/code-utils");
const find_module_1 = require("@schematics/angular/utility/find-module");
const parse_name_1 = require("@schematics/angular/utility/parse-name");
const yang_utils_1 = require("../utils/yang-utils");
function default_1(options) {
    return (host) => {
        const rootPath = yang_utils_1.getSourceRoot(host, options);
        yang_utils_1.smartPath(rootPath, options, '');
        if (!options.path) {
            options.path = `${rootPath}/shared`;
        }
        const parsedPath = parse_name_1.parseName(options.path, options.name);
        options.path = parsedPath.path;
        options.module = yang_utils_1.findClosestModule(host, options, 'shared');
        const templateSource = schematics_1.apply(schematics_1.url('./files'), [
            options.routing ? schematics_1.noop() : schematics_1.filter(path => !path.endsWith('-routing.module.ts')),
            schematics_1.template(Object.assign(Object.assign(Object.assign({}, core_1.strings), { 'if-flat': (s) => options.flat ? '' : s }), options)),
            schematics_1.move(options.path)
        ]);
        const createComp = options.component ? schematics_1.schematic('component', {
            project: options.project,
            name: options.name,
            path: options.path + '/' + options.name,
            routing: true,
            route: ''
        }) : schematics_1.noop();
        return schematics_1.chain([
            schematics_1.mergeWith(templateSource),
            createComp,
            addNgModule(options)
        ]);
    };
}
exports.default = default_1;
function addNgModule(options) {
    return (host) => {
        if (!options.module)
            return host;
        const file = options.module;
        const sourceFile = code_utils_1.CodeUtils.readSourceFile(host, file);
        const modulePath = `/${options.path}/`
            + (options.flat ? '' : core_1.strings.dasherize(options.name) + '/')
            + core_1.strings.dasherize(options.name)
            + '.module';
        const relativePath = find_module_1.buildRelativePath(options.module, modulePath);
        code_utils_1.CodeUtils.addImport(sourceFile, `${core_1.strings.classify(options.name)}Module`, relativePath);
        code_utils_1.CodeUtils.insertInVariableArray(sourceFile, "MODULES", `${core_1.strings.classify(options.name)}Module`);
        code_utils_1.CodeUtils.writeSourceFile(host, file, sourceFile);
        return host;
    };
}
//# sourceMappingURL=index.js.map