"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeUtils = void 0;
const schematics_1 = require("@angular-devkit/schematics");
const ts_morph_1 = require("ts-morph");
const string_utils_1 = require("./string-utils");
class CodeUtils {
    static readSourceFile(host, file) {
        const text = host.read(file);
        if (text === null) {
            throw new schematics_1.SchematicsException(`File ${file} does not exist.`);
        }
        const sourceText = text.toString('utf-8');
        return CodeUtils.getSourceFile(file, sourceText);
    }
    static writeSourceFile(host, file, sourceFile) {
        host.overwrite(file, sourceFile.getFullText());
    }
    static formatText(block) {
        block.formatText({
            indentSize: 2
        });
    }
    static getSourceFile(file, content) {
        const project = new ts_morph_1.Project({
            useInMemoryFileSystem: true,
            manipulationSettings: {
                quoteKind: ts_morph_1.QuoteKind.Single
            }
        });
        project.createSourceFile(file, content);
        let sourceFile = project.getSourceFile(file);
        if (!sourceFile) {
            sourceFile = project.createSourceFile(file, content);
        }
        return sourceFile;
    }
    static getVariableDeclaration(sourceFile, variableName) {
        let varDeclaration = sourceFile.getVariableDeclaration(variableName);
        if (!varDeclaration) {
            throw new Error(`Cannot find variable '${variableName}' in file '${sourceFile.getFilePath()}'`);
        }
        return varDeclaration;
    }
    static insertInVariableArray(sourceFile, variableName, str) {
        let varDeclaration = CodeUtils.getVariableDeclaration(sourceFile, variableName);
        let block = varDeclaration.getText();
        block = CodeUtils.insertInArray(block, str);
        varDeclaration.replaceWithText(block);
        CodeUtils.formatText(CodeUtils.getVariableDeclaration(sourceFile, variableName));
    }
    static insertInVariableObject(sourceFile, variableName, str) {
        let varDeclaration = CodeUtils.getVariableDeclaration(sourceFile, variableName);
        let block = varDeclaration.getText();
        block = CodeUtils.insertInObject(block, str);
        varDeclaration.replaceWithText(block);
        CodeUtils.formatText(CodeUtils.getVariableDeclaration(sourceFile, variableName));
    }
    static insertInArray(block, str) {
        return CodeUtils.insertInBlock(block, str, '[', ']');
    }
    static insertInObject(block, str) {
        return CodeUtils.insertInBlock(block, str, '{', '}');
    }
    static insertInBlock(block, str, startDelimiter, endDelimiter) {
        let startObj = block.lastIndexOf(startDelimiter);
        let endObj = block.lastIndexOf(endDelimiter);
        let objStr = block.substring(startObj, endObj + 1);
        // Retrouver le dernier caractère
        let startNdx = string_utils_1.StringUtils.findLast(objStr.substr(0, objStr.length - 1), /[a-z0-9\}\)]/i);
        let comma = "";
        if (startNdx < 0) {
            startNdx = 1;
        }
        else {
            startNdx++;
            comma = ',';
        }
        objStr = [objStr.slice(0, startNdx), `${comma}\r\n${str}`, objStr.slice(startNdx)].join('');
        return [block.slice(0, startObj), objStr, block.slice(endObj + 1)].join('');
    }
    static addImport(sourceFile, importName, importFile) {
        if (!importName) {
            sourceFile.addImportDeclaration({
                moduleSpecifier: importFile
            });
        }
        else if (importName.includes(" as ")) {
            if (importName.startsWith('*')) {
                sourceFile.addImportDeclaration({
                    defaultImport: importName,
                    moduleSpecifier: importFile
                });
            }
            else {
                sourceFile.addImportDeclaration({
                    namedImports: [importName],
                    moduleSpecifier: importFile
                });
            }
        }
        else {
            sourceFile.addImportDeclaration({
                namedImports: [{ name: importName }],
                moduleSpecifier: importFile
            });
        }
    }
}
exports.CodeUtils = CodeUtils;
//# sourceMappingURL=code-utils.js.map