"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.installDeps = exports.sortByKey = exports.findClosestModule = exports.smartPath = exports.getProjectSchematic = exports.getProjectSchematics = exports.getSourceRoot = exports.getProjectRoot = exports.getProjectName = exports.forceOverwrite = exports.YangUtils = void 0;
const schematics_1 = require("@angular-devkit/schematics");
const config_1 = require("@schematics/angular/utility/config");
const workspace_1 = require("@schematics/angular/utility/workspace");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const find_module_1 = require("@schematics/angular/utility/find-module");
class YangUtils {
}
exports.YangUtils = YangUtils;
YangUtils.MAIN_FILE = '/src/main.ts';
YangUtils.CORE_MODULE_FILE = '/src/app/core/core.module.ts';
YangUtils.SHARED_MODULE_FILE = '/src/app/shared/shared.module.ts';
YangUtils.FEATURES_MODULE_FILE = '/src/app/features/features.module.ts';
YangUtils.ROUTING_MODULE_FILE = '/src/app/app-routing.module.ts';
function forceOverwrite(host) {
    return schematics_1.forEach((entry) => {
        if (host.exists(entry.path)) {
            host.overwrite(entry.path, Buffer.from(''));
            host.overwrite(entry.path, Buffer.from(entry.content));
        }
        return entry;
    });
}
exports.forceOverwrite = forceOverwrite;
function getProjectName(host, options) {
    var _a;
    return (_a = options.project) !== null && _a !== void 0 ? _a : config_1.getWorkspace(host).defaultProject;
}
exports.getProjectName = getProjectName;
function getProjectRoot(host, options, suffix = false) {
    var _a;
    const workspace = config_1.getWorkspace(host);
    if (!options.project) {
        options.project = workspace.defaultProject;
    }
    const project = workspace.projects[options.project];
    let projectRoot = (_a = project.root) !== null && _a !== void 0 ? _a : '';
    if (suffix && projectRoot) {
        projectRoot += '/';
    }
    return projectRoot;
}
exports.getProjectRoot = getProjectRoot;
function getSourceRoot(host, options) {
    const workspace = config_1.getWorkspace(host);
    if (!options.project) {
        options.project = workspace.defaultProject;
    }
    const project = workspace.projects[options.project];
    const projectDirName = project.projectType === 'application' ? 'app' : 'lib';
    return `/${project.root}/src/${projectDirName}`;
}
exports.getSourceRoot = getSourceRoot;
function getProjectSchematics(host, options) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const workspace = yield workspace_1.getWorkspace(host);
        const project = workspace.projects.get(options.project);
        if (!project) {
            return;
        }
        return (_a = project.extensions.schematics) !== null && _a !== void 0 ? _a : {};
    });
}
exports.getProjectSchematics = getProjectSchematics;
function getProjectSchematic(host, options, schematicName) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const schematics = yield getProjectSchematics(host, options);
        return (_a = schematics[schematicName]) !== null && _a !== void 0 ? _a : {};
    });
}
exports.getProjectSchematic = getProjectSchematic;
function smartPath(rootPath, options, sharedSubFolder) {
    if (options.path) {
        return;
    }
    if (!options.name.includes('/')) {
        return;
    }
    const nameArgs = options.name.split('/');
    const classifier = nameArgs.shift();
    options.name = nameArgs.pop();
    if ('shared' === classifier) {
        if (sharedSubFolder && nameArgs.length === 0) {
            nameArgs.unshift(sharedSubFolder);
        }
        nameArgs.unshift('shared');
    }
    else {
        nameArgs.unshift('features', classifier);
    }
    options.path = `${rootPath}/${nameArgs.join('/')}`;
}
exports.smartPath = smartPath;
function findClosestModule(host, options, defaultModule) {
    try {
        return find_module_1.findModuleFromOptions(host, options);
    }
    catch (err) {
        if (!options.module) {
            const opt = Object.assign(Object.assign({}, options), { module: defaultModule });
            return find_module_1.findModuleFromOptions(host, opt);
        }
        else {
            throw err;
        }
    }
}
exports.findClosestModule = findClosestModule;
function sortByKey(unsorted) {
    const ordered = {};
    Object.keys(unsorted).sort().forEach((key) => {
        ordered[key] = unsorted[key];
    });
    return ordered;
}
exports.sortByKey = sortByKey;
function installDeps(skipInstall) {
    return (host, context) => {
        if (!skipInstall)
            context.addTask(new tasks_1.NodePackageInstallTask());
    };
}
exports.installDeps = installDeps;
//# sourceMappingURL=yang-utils.js.map